@@ -6,8 +6,9 @@ from os.path import join
 from urllib.request import urlretrieve
 
 from django.apps import AppConfig
+from django.conf import settings
 
-from .templatetags import MERMAID_VERSION
+from .templatetags import DEFAULT_VERSION
 
 
 class MermaidConfig(AppConfig):
@@ -15,9 +16,10 @@ class MermaidConfig(AppConfig):
 
     def ready(self):
         """Download mermaid.js from CDN if not already present"""
-        cdn = "https://cdnjs.cloudflare.com/ajax/libs/mermaid/%s/mermaid.min.js" % MERMAID_VERSION
+        version = getattr(settings, "MERMAID_VERSION", DEFAULT_VERSION)
+        cdn = "https://cdnjs.cloudflare.com/ajax/libs/mermaid/%s/mermaid.min.js" % version
         static_dir = join(dirname(__file__), "static")
-        mermaid_dir = join(static_dir, "mermaid", MERMAID_VERSION)
+        mermaid_dir = join(static_dir, "mermaid", version)
         if not exists(join(mermaid_dir, "mermaid.js")) or \
                 stat(join(mermaid_dir, "mermaid.js")).st_size == 0:
             dir_util.create_tree(mermaid_dir, ["mermaid.js"])
